"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
class BorumRequest {
    constructor(input, init) {
        this.headers = {};
        this.init = init || {};
        this.url = input;
    }
    static initialize(input, init) {
        return new BorumRequest(`https://api.borumtech.com/api/${input}`, init);
    }
    authorize(userApiKey = localStorage.getItem("userApiKey")) {
        Object.assign(this.headers, {
            "authorization": `Basic ${userApiKey}`
        });
        return this;
    }
    post(body) {
        Object.assign(this.init, {
            body,
            method: "POST"
        });
        Object.assign(this.headers, {
            "content-type": "application/x-www-form-urlencoded"
        });
        return this;
    }
    put(body) {
        Object.assign(this.init, {
            body,
            method: "PUT"
        });
        Object.assign(this.headers, {
            "content-type": "application/x-www-form-urlencoded"
        });
        return this;
    }
    delete(body) {
        Object.assign(this.init, {
            body,
            method: "DELETE"
        });
        Object.assign(this.headers, {
            "content-type": "application/x-www-form-urlencoded"
        });
        return this;
    }
    makeRequest(abortController = new AbortController()) {
        return __awaiter(this, void 0, void 0, function* () {
            this.init = Object.assign(Object.assign({}, this.init), { headers: this.headers, signal: abortController.signal });
            // Abort the request if it takes too long to give a response
            setTimeout(() => abortController.abort(), 5000);
            const response = yield fetch(this.url, this.init);
            if (response.status >= 200 && response.status < 300) {
                return yield response.json();
            }
            const { error } = yield response.json();
            throw new Error(error.message);
        });
    }
}
